@@ -60,8 +60,10 @@ def gridanalysis(NAME,FILES,SERIES,ow_start,ow_finish,windows,stride,NumProc,dt,
                     if(NumProc > 1 ):
                         pool.apply_async(svolfit,args=(series.copy(), dt, model, method, modeloptions.copy(), RunPars.copy()),callback=lambda x: solsm.append(x) )
                     else:
-                        (rpdict,sol)=svolfit( series, dt, model, method, modeloptions.copy(), RunPars.copy() )
+                        (status,message,rpdict,sol)=svolfit( series, dt, model, method, modeloptions.copy(), RunPars.copy() )
                         ssl={}
+                        ssl['status']=status
+                        ssl['message']=message
                         ssl.update(rpdict)
                         ssl.update(sol)
                         sols.append(ssl)
@@ -72,8 +74,10 @@ def gridanalysis(NAME,FILES,SERIES,ow_start,ow_finish,windows,stride,NumProc,dt,
         pool.join()
         for x in solsm:
             ssl={}
-            ssl.update(x[0])
-            ssl.update(x[1])
+            ssl['status']=x[0]
+            ssl['message']=x[1]
+            ssl.update(x[2])
+            ssl.update(x[3])
             sols.append(ssl)
     
     sols=pd.DataFrame(sols)
@@ -86,13 +90,19 @@ def gridanalysis(NAME,FILES,SERIES,ow_start,ow_finish,windows,stride,NumProc,dt,
         upaths = pd.DataFrame(sols.ts_upath.tolist(),index=sols.index)
         upaths.columns=['upath_'+str(x) for x in upaths.columns]
         upaths.T.to_csv(NAME+'_'+model+'_'+method+'_raw_upaths.csv')
+        sols.drop(['ts_upath'],axis=1,inplace=True)
 
     if('ts_vpath' in sols):
         vpaths = pd.DataFrame(sols.ts_vpath.tolist(),index=sols.index)
         vpaths.columns=['vpath_'+str(x) for x in vpaths.columns]        
         vpaths.T.to_csv(NAME+'_'+model+'_'+method+'_raw_vpaths.csv')
+        sols.drop(['ts_vpath'],axis=1,inplace=True)
 
-    sols.drop(['ts_upath','ts_vpath'],axis=1,inplace=True)
+    if('ts_standardreturns' in sols):
+        standardreturns = pd.DataFrame(sols.ts_standardreturns.tolist(),index=sols.index)
+        standardreturns.columns=['standardreturn_'+str(x) for x in standardreturns.columns]        
+        standardreturns.T.to_csv(NAME+'_'+model+'_'+method+'_raw_standardreturns.csv')
+        sols.drop(['ts_standardreturns'],axis=1,inplace=True)
 
     sols.to_csv(NAME+'_'+model+'_'+method+'_raw.csv')
 
