@@ -45,9 +45,7 @@ class Bates_tree(Heston_tree):
 # careful needs unscaled lambda:
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
         r=np.maximum(r_lower,r)
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
 
         lamb = lamb/self.lamb_scaling
         lamb_lower = lamb_lower/self.lamb_scaling
@@ -143,9 +141,7 @@ class Bates_tree(Heston_tree):
         u0=v0/theta
 
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
         lamb = lamb / self.lamb_scaling
 
         if( pardict['type']=='init' ):
@@ -441,9 +437,7 @@ class Bates_treeX2(Heston_treeX2):
 # careful needs unscaled lambda:
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
         r=np.maximum(r_lower,r)
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
 
         s=sigma*np.sqrt(1.0+r*r)    
 
@@ -541,9 +535,7 @@ class Bates_treeX2(Heston_treeX2):
         u0=v0/theta
 
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
         lamb = lamb / self.lamb_scaling
 
         if( pardict['type']=='init' ):
@@ -828,9 +820,7 @@ class Bates_grid(Heston_grid):
 # careful needs unscaled lambda:
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
         r=np.maximum(r_lower,r)
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
 
         lamb = lamb/self.lamb_scaling
         lamb_lower = lamb_lower/self.lamb_scaling
@@ -911,9 +901,7 @@ class Bates_grid(Heston_grid):
         u0=v0/theta
 
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
         lamb = lamb / self.lamb_scaling
 
         if( pardict['type']=='init' ):
