@@ -44,9 +44,7 @@ class GARCHjdiff_grid(GARCHdiff_grid):
 # careful needs unscaled lambda:
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
         r=np.maximum(r_lower,r)
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
 
         lamb = lamb/self.lamb_scaling
         lamb_lower = lamb_lower/self.lamb_scaling
@@ -126,9 +124,7 @@ class GARCHjdiff_grid(GARCHdiff_grid):
         u0=v0/theta
 
         r=np.sqrt(lamb*(gamm*gamm+omeg*omeg))/sigma
-        phi=0.0
-        if( omeg > 0.0 ):
-            phi=math.atan(gamm/omeg)
+        phi=math.atan2(gamm,omeg)
         lamb = lamb / self.lamb_scaling
 
         if( pardict['type']=='init' ):
