@@ -17,7 +17,8 @@ class HestonNandi_v(svol_model):
     def _init_d(self):
         mu=0.0
         sigma=0.1
-        (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+        if( len(self.series)>1 ):
+	        (mu,sigma)=meanvariance(np.array(self.series),self.dt)
         alpha=2.0
         xi=1.0
         u0=1.0
@@ -34,12 +35,15 @@ class HestonNandi_v(svol_model):
 
         self.workingpars_names=['mu','sigma','alpha','xi','u0']
         self.workingpars=np.array([mu,sigma,alpha,xi,u0])
+        self.workingpars_sim=np.array([mu,sigma,alpha,xi,u0])
         self.workingpars_diffs=[0.0001,0.0001,0.001,0.0001,0.0001]
 
         alpha_min=np.minimum(2.0/((self.Nobs-1)/252.0),1.0)
 #                 [hmu, hsigma, rho, alpha, xi,u0]
         self.workingpars_bounds=[(-0.5,0.5), (0.05, 0.5), (alpha_min, 20.0), (0.1, 4.0),(0.1,3.0)]
 
+        self.workingpars_optflag=[True,True,True,True,True]
+
         if 'init' in self.options:
             self.initpars_reporting(self.options['init'])
 
@@ -87,22 +91,29 @@ class HestonNandi_v(svol_model):
         xi=eta/sigma
         u0=v0/theta
         
-        self.workingpars[0]=mu
-        self.workingpars[1]=sigma
-        self.workingpars[2]=alpha
-        self.workingpars[3]=xi
-        self.workingpars[4]=u0
-
+        if( pardict['type']=='init' ):
+            self.workingpars[0]=mu
+            self.workingpars[1]=sigma
+            self.workingpars[2]=alpha
+            self.workingpars[3]=xi
+            self.workingpars[4]=u0
+            self.eps=eps
+        else:
+            self.workingpars_sim[0]=mu
+            self.workingpars_sim[1]=sigma
+            self.workingpars_sim[2]=alpha
+            self.workingpars_sim[3]=xi
+            self.workingpars_sim[4]=u0
         self.eps=eps
-
+            
         return
 
     def get_structure(self):
         assetname='asset'
         variancename='variance'
 
-        sigma=self.workingpars[1]
-        u0=self.workingpars[4]
+        sigma=self.workingpars_sim[1]
+        u0=self.workingpars_sim[4]
 
         corrmatrix=np.array([1.0])
 #TODO: best choice based on pars?
@@ -114,10 +125,10 @@ class HestonNandi_v(svol_model):
         return assetname,assetval,variancename,varianceval,corrmatrix,Nperstep
     
     def sim_step(self,asset,variance,Zs):
-        mu=self.workingpars[0] 
-        sigma=self.workingpars[1]
-        alpha=self.workingpars[2] 
-        xi=self.workingpars[3]
+        mu=self.workingpars_sim[0] 
+        sigma=self.workingpars_sim[1]
+        alpha=self.workingpars_sim[2] 
+        xi=self.workingpars_sim[3]
 
         eps = self.eps
         
@@ -170,49 +181,70 @@ class HestonNandi_v(svol_model):
         ret['misc_rho']=self.eps
         ret['rep_alpha']=alpha
         ret['rep_eta']=eta
-        ret['misc_q']=q
 #        ret['u0']=u0
-#        ret['uT']=uT
         ret['rep_v0']=v0
-        ret['rep_vT']=vT
+
+        sim_mu=self.workingpars_sim[0] 
+        sim_sigma=self.workingpars_sim[1]
+        sim_alpha=self.workingpars_sim[2] 
+        sim_xi=self.workingpars_sim[3]
+        sim_u0=self.workingpars_sim[4]
+
+        sim_theta=sim_sigma*sim_sigma
+        sim_eta=sim_xi*sim_sigma
+        sim_v0=sim_sigma*sim_sigma*sim_u0
+
+        ret['sim_wrk_mu']=sim_mu
+        ret['sim_wrk_sigma']=sim_sigma
+        ret['sim_wrk_alpha']=sim_alpha
+        ret['sim_wrk_xi']=sim_xi
+        ret['sim_wrk_u0']=sim_u0
+
+        ret['sim_rep_mu']=sim_mu
+        ret['sim_rep_theta']=sim_theta
+        ret['sim_rep_alpha']=sim_alpha
+        ret['sim_rep_eta']=sim_eta
+        ret['sim_rep_v0']=sim_v0
+
+
+        ret['misc_q']=q
+        ret['misc_vT']=vT
+#        ret['uT']=uT
         ret['ts_vpath']=vpath
         ret['ts_upath']=self.upath
         
         return ret
 
-    def workingpars_update(self,workingpars):
-        super().workingpars_update(workingpars)
+    def update(self):
+        super().update()
 
-        if( self.current==False):
-# update all grid quantities to be cached:
-#TODO: struct-ify?
-            mu=self.workingpars[0] 
-            sigma=self.workingpars[1]
-            alpha=self.workingpars[2] 
-            xi=self.workingpars[3]
-            u0=self.workingpars[4]
+        mu=self.workingpars[0] 
+        sigma=self.workingpars[1]
+        alpha=self.workingpars[2] 
+        xi=self.workingpars[3]
+        u0=self.workingpars[4]
 
-            q=2.0*alpha/(xi*xi)
+        q=2.0*alpha/(xi*xi)
  
-            eps = self.eps
-            dt=self.dt
+        eps = self.eps
+        dt=self.dt
 
-            if(alpha*dt<1.0e-8):
-                self.c=2.0/(xi*xi*dt)
-            else:
-                self.c=-q/np.expm1(-alpha*dt)
+        if(alpha*dt<1.0e-8):
+            self.c=2.0/(xi*xi*dt)
+        else:
+            self.c=-q/np.expm1(-alpha*dt)
 
 # populate the u vector here, calculate probs elsewhere:
-            coeff_dt=(mu-eps*alpha*sigma/xi)*dt        
-            coeff_udt=(eps*alpha*sigma/xi-sigma*sigma/2.0)*dt        
-            coeff_du=eps*sigma/xi
-            coeff_du+=(eps*alpha*sigma/xi-sigma*sigma/2.0)*dt/2.0
-            
-            self.upath[0]=u0
-            utol=0.0*1.0e-8
-            for cc in range(1,self.Nobs):
-                self.upath[cc]=self.upath[cc-1]+(self.yasset[cc-1]-coeff_dt-coeff_udt*self.upath[cc-1])/coeff_du
-                self.upath[cc]=np.maximum(utol,self.upath[cc])
+        coeff_dt=(mu-eps*alpha*sigma/xi)*dt        
+        coeff_udt=(eps*alpha*sigma/xi-sigma*sigma/2.0)*dt        
+        coeff_du=eps*sigma/xi
+        coeff_du+=(eps*alpha*sigma/xi-sigma*sigma/2.0)*dt/2.0
+        
+        self.upath[0]=u0
+        utol=1.0e-4
+        for cc in range(1,self.Nobs):
+            self.upath[cc]=self.upath[cc-1]+(self.yasset[cc-1]-coeff_dt-coeff_udt*self.upath[cc-1])/coeff_du
+            self.upath[cc]=np.maximum(utol,self.upath[cc])
 
         return
 
@@ -260,7 +292,8 @@ class HestonNandi_v(svol_model):
 #                lnprobs[cc]+=z+np.log(ive(q-1.0,z))
 
         SIG=sigma*np.sqrt( (self.upath[0:Nret]+self.upath[1:Nret+1]+np.sqrt(self.upath[0:Nret]*self.upath[1:Nret+1]))*dt/3.0 )
-        m=mu*dt-0.5*SIG
+#        SIG=sigma*np.sqrt( (self.upath[0:Nret]+self.upath[1:Nret+1])*dt/2.0 )
+        m=mu*dt-0.5*SIG*SIG
         ZN=(self.yasset-m)/SIG
         lnprobs[:]=-0.5*ZN*ZN-0.5*np.log(2*np.pi)-0.5*np.log(SIG)
 
@@ -282,5 +315,13 @@ class HestonNandi_v(svol_model):
     def variancepath(self):
         return 
     
+    def status(self):
+        if self.current != True:
+            return 'Failure','Incorrect Model State.'
+
+        status = 'Success'
+        message = 'No issues.'        
+        return (status,message)
+
+ 
     
-    
\ No newline at end of file
