@@ -6,10 +6,10 @@ from svolfit.models.PureJump import PureJump_grid
 from svolfit.models.HestonNandi import HestonNandi_v
 from svolfit.models.Heston import Heston_grid,Heston_tree,Heston_treeX2
 from svolfit.models.Bates import Bates_grid,Bates_tree,Bates_treeX2
-from svolfit.models.H32 import H32_grid,H32_tree,H32_treeX2
-from svolfit.models.B32 import B32_grid,B32_tree,B32_treeX2
-from svolfit.models.GARCHdiff import GARCHdiff_grid,GARCHdiff_tree,GARCHdiff_treeX2
-from svolfit.models.GARCHjdiff import GARCHjdiff_grid,GARCHjdiff_tree,GARCHjdiff_treeX2
+from svolfit.models.H32 import H32_grid
+from svolfit.models.B32 import B32_grid
+from svolfit.models.GARCHdiff import GARCHdiff_grid
+from svolfit.models.GARCHjdiff import GARCHjdiff_grid
 from svolfit.models.Heston_GBM import Heston_GBM_grid,Heston_GBM_tree,Heston_GBM_treeX2
 
 def model_create(series, dt, model, method,options):
@@ -56,37 +56,21 @@ def model_create(series, dt, model, method,options):
         else:
             print(model+' with unknown method: '+method)
     elif( model == 'H32' ):
-#        if( method == 'tree' ):
-#            modelobj = H32_tree(series,dt, model, method,options)
-#        elif( method == 'treeX2' ):
-#            modelobj = H32_treeX2(series,dt, model, method,options)
         if( method == 'grid' ):
             modelobj = H32_grid(series,dt, model, method,options)
         else:
             print(model+' with unknown method: '+method)
     elif( model == 'B32' ):
-#        if( method == 'tree' ):
-#            modelobj = B32_tree(series,dt, model, method,options)
-#        elif( method == 'treeX2' ):
-#            modelobj = B32_treeX2(series,dt, model, method,options)
         if( method == 'grid' ):
             modelobj = B32_grid(series,dt, model, method,options)
         else:
             print(model+' with unknown method: '+method)
     elif( model == 'GARCHdiff' ):
-#        if( method == 'tree' ):
-#            modelobj = GARCHdiff_tree(series,dt, model, method,options)
-#        elif( method == 'treeX2' ):
-#            modelobj = GARCHdiff_treeX2(series,dt, model, method,options)
         if( method == 'grid' ):
             modelobj = GARCHdiff_grid(series,dt, model, method,options)
         else:
             print(model+' with unknown method: '+method)
     elif( model == 'GARCHjdiff' ):
-#        if( method == 'tree' ):
-#            modelobj = GARCHjdiff_tree(series,dt, model, method,options)
-#        elif( method == 'treeX2' ):
-#            modelobj = GARCHjdiff_treeX2(series,dt, model, method,options)
         if( method == 'grid' ):
             modelobj = GARCHjdiff_grid(series,dt, model, method,options)
         else:
