@@ -1,12 +1,13 @@
 import time
-from scipy.optimize import minimize
+#from scipy.optimize import minimize
+from scipy import optimize
 
 from svolfit.models.model_factory import model_create
 
 def svolfit( series, dt, model='Heston', method = 'grid', modeloptions={}, RunInfo={} ):
 
-    sol_success=False
-    sol_message='Incomplete'
+    status='Failed'
+    message='Incomplete'
 
     sol = {}
     sol['RunInfo_'+'model']=model
@@ -19,11 +20,10 @@ def svolfit( series, dt, model='Heston', method = 'grid', modeloptions={}, RunIn
     try:
         model=model_create(series, dt, model, method, modeloptions )
     except:
-        sol['success']=sol_success
-        sol['message']='Model creation failed.'
+        message='Model creation failed.'
         sol['ts_upath']=[]
         sol['ts_vpath']=[]
-        return {},sol
+        return status,message,{},sol
     
     (wpn,wp,wpb)=model.get_workingpars()
     for cc in range(0,len(wpn)):
@@ -40,7 +40,8 @@ def svolfit( series, dt, model='Heston', method = 'grid', modeloptions={}, RunIn
     opts={'disp': True, 'ftol': 1.0e-8}
     start_time = time.process_time()
 
-    res = minimize(lambda x: model.objective_calculate(x), wp, jac=lambda x: model.calculate_gradient(x),method='SLSQP',bounds=wpb,constraints=mcons,options=opts)
+    res = optimize.minimize(lambda x: model.objective_calculate(x), wp, jac=lambda x: model.calculate_gradient(x),method='SLSQP',bounds=wpb,constraints=mcons,options=opts)
+#    res = optimize.differential_evolution(lambda x: model.objective_calculate(x), bounds=wpb,constraints=mcons,popsize=150,disp=True)
 
     for x in res:
         sol['opt_'+x]=res[x]
@@ -64,6 +65,10 @@ def svolfit( series, dt, model='Heston', method = 'grid', modeloptions={}, RunIn
         sol['ts_vpath']=rdict['ts_vpath']
     else:
         sol['ts_vpath']=[]
+    if( 'ts_standardreturns' in rdict ):
+        sol['ts_standardreturns']=rdict['ts_standardreturns']
+    else:
+        sol['ts_standardreturns']=[]
     
     elapsed_time = time.process_time() - start_time
     sol['proctime']=elapsed_time
@@ -84,17 +89,15 @@ def svolfit( series, dt, model='Heston', method = 'grid', modeloptions={}, RunIn
     for x in stdict:
         sol['stat_'+x]=stdict[x]
 
-    if( stdict['current'] == True ):
-        sol_success=True
-        sol_message='Optimization succeeded.'
-    else:
-        sol_success=False
-        sol_message='Incorrect model state.'
-        
-    sol['success']=sol_success
-    sol['message']=sol_message
+    (status,message)=model.status()
+    sol['model_status']=status
+    sol['model_message']=message
+
+    if( res['success']!=True ):
+        status='Failed'
+        message='Optimization unsuccessful.'
+                
+    print(status,message,sol['proctime'],sol['opt_fun'],RunInfo)
     
-    print(sol_success,sol['proctime'],sol['opt_fun'],RunInfo)
-    
-    return (rpdict,sol)
+    return (status,message,rpdict,sol)
 
